package App::Acmeman::Source::File;

use strict;
use warnings;
use Carp;
use File::Spec;
use parent 'App::Acmeman::Source';

sub new {
    my $class = shift;
    my $pattern = shift || croak "file name or globbing pattern must be given";
    my $ignore = '^\.|~$|\.bak$|^#.*#$';
    unless ($pattern =~ m{[][*?]}) {
	$pattern =~ s{/$}{};
	$pattern = File::Spec->catfile($pattern, '*');
    }
    bless { pattern => $pattern, ignore => $ignore }, $class;
}

sub scan {
    my ($self) = @_;
    $self->debug(1, "initializing file list from $self->{pattern}");
    my $err = 0;
    foreach my $file (glob $self->{pattern}) {
	next if $file =~ m{$self->{ignore}};
	$err |= $self->load($file);
    }
    return $err == 0;
}

sub load {
    my ($self, $file) = @_;
    $self->debug(1, "reading $file");
    open(my $fh, '<', $file)
	or do {
	    $self->error("can't open $file: $!");
	    return 0;
    };
    chomp(my @lines = <$fh>);
    close $fh;
    my $cn = shift @lines;
    $self->define_domain($cn);
    $self->define_alias($cn, @lines);
    return 1;
}

1;

    
